@@ -46,7 +46,7 @@ def collect_information(bin_precision,bin_width,percent):
 		print('step_6:',n,window,total_number)
 		file_df=pd.read_csv(file_path,converters={'Tmass':str})
 		file_df=file_df[file_df['status']=='use']
-		grouped=file_df.groupby(['group'])
+		grouped=file_df.groupby('group')
 		for name,group in grouped:
 			if len(group)<total_sample_number*percent:
 				continue
