@@ -14,7 +14,6 @@ def collect_bins(bin_width,bin_precision,dict_size):
 	
 	result_dir='shift_result_bins'
 	
-	
 	if not os.path.exists(result_dir):
 		os.mkdir(result_dir)
 	
@@ -39,7 +38,7 @@ def collect_bins(bin_width,bin_precision,dict_size):
 					bin_2_f=bin_1_f+bin_width
 					bin_1=str(round(bin_1_f,bin_precision))
 					bin_2=str(round(bin_2_f,bin_precision))
-					batch_number=int(bin_1_f*math.pow(10,bin_precision)/1000)
+					batch_number=int(float(bin_1)*math.pow(10,bin_precision)/1000)
 					new_key=result_dir+'/'+str(batch_number)+'/'+bin_1+'_'+bin_2+'.csv'
 					if new_key in shift_result:
 						shift_result[new_key]=shift_result[new_key]+sample+','+fraction+','+oneline
