@@ -13,7 +13,7 @@ import pandas as pd
 import multiprocessing as mp
 import os
 
-def mass_filter(file_dir,file,result_dir):
+def mass_filter(file_dir,file,result_dir,min_time_diff):
 	df=pd.read_csv(file_dir+'/'+file,converters={'Tmass':str})
 	grouped=df.groupby(['sample','fraction'])
 	for name,group in grouped:
@@ -28,12 +28,12 @@ def mass_filter(file_dir,file,result_dir):
 					group_sort.drop(index,axis=0,inplace=True)
 				else:
 					time=group_sort.loc[index]['Ttime']
-					if abs(time-time_begin)<1:
+					if abs(time-time_begin)<min_time_diff:
 						m=m+1
 						group_sort.drop(index,axis=0,inplace=True)
 						df.drop(index,axis=0,inplace=True)
 	df.to_csv(result_dir+'/'+file,index=False)
-def run_mass_filter(processing_number):
+def run_mass_filter(processing_number,min_time_diff):
 	file_dir='shift_result_bins'
 	result_dir='shift_result_bins_filter'
 	
@@ -46,10 +46,11 @@ def run_mass_filter(processing_number):
 		file_arg.append(file_dir)
 		file_arg.append(file)
 		file_arg.append(result_dir)
+		file_arg.append(min_time_diff)
 		pool_arg.append(file_arg)
 	print('step_4: running')
 	pool=mp.Pool(processes=processing_number)
-	result = pool.starmap_async(mass_filter,pool_arg)
+	pool.starmap_async(mass_filter,pool_arg)
 	pool.close()
 	pool.join()
 	print('step_4: finish')
\ No newline at end of file
