@@ -90,8 +90,8 @@ def sample_pretreat(filepath,sample,fraction,result_dir):
 		erro_files.close()
 		return False
 	df=pd.DataFrame(XICs)
-	drop_negative=df[df['charge']==1].index
-	df.drop(drop_negative,inplace=True)
+	#drop_negative=df[df['charge']==1].index
+	#df.drop(drop_negative,inplace=True)
 	Tmz=[str(round(a,3))for a in df['mz']]
 	df.loc[:,'Tmz']=Tmz
 	base=314448000000
@@ -99,7 +99,8 @@ def sample_pretreat(filepath,sample,fraction,result_dir):
 	Tintensity=[math.log2(a/sum_of_intensity*base)for a in df['intensity']]
 	Tintensity10=[math.log10(a/sum_of_intensity*base)for a in df['intensity']]
 	df.loc[:,'Tintensity']=Tintensity
-	Tmass=[str(round(c*float(d)-c*1.007276,2)) for c,d in zip(df['charge'],df['Tmz'])]
+	#Tmass=[str(round(c*float(d)-c*1.007276,2)) for c,d in zip(df['charge'],df['Tmz'])]
+	Tmass=[str(round(a,2))for a in df['mz']]
 	df.loc[:,'Tmass']=Tmass
 	df.loc[:,'Tintensity10']=Tintensity10
 	Pintensity=[a/sum_of_intensity for a in df['intensity']]
@@ -111,6 +112,7 @@ def sample_pretreat(filepath,sample,fraction,result_dir):
 	if not os.path.exists(result_dir+'/'+fraction):
 		os.mkdir(result_dir+'/'+fraction)
 	df.to_csv(result_dir+'/'+fraction+'/'+sample+'.csv',index=False)
+	file.close()
 	return True
 
 
@@ -122,8 +124,8 @@ def pre_step(file_dir,sample_file):
 	rows = booksheet.nrows
 	for i in range(rows):
 		raw_name = booksheet.cell_value(i,0).split('.')[0]
-		sample_name = booksheet.cell_value(i,1)
-		fraction_name = booksheet.cell_value(i,2)
+		sample_name = str(booksheet.cell_value(i,1))
+		fraction_name = str(booksheet.cell_value(i,2))
 		file_class_dics[raw_name] = sample_name
 		file_fraction_dics[raw_name] = fraction_name
 	result_dir='pre_result'
