@@ -88,8 +88,8 @@ def sample_pretreat(filepath,sample,fraction,result_dir):
 		erro_files.close()
 		return False
 	df=pd.DataFrame(XICs)
-	drop_negative=df[(df['charge']==1)|(df['intensity']<0)].index
-	df.drop(drop_negative,inplace=True)
+	#drop_negative=df[(df['charge']==1)|(df['intensity']<0)].index
+	#df.drop(drop_negative,inplace=True)
 	Tmz=[str(round(a,3))for a in df['mz']]
 	df.loc[:,'Tmz']=Tmz
 	base=189346000000
@@ -104,13 +104,15 @@ def sample_pretreat(filepath,sample,fraction,result_dir):
 	df.loc[:,'Pintensity']=Pintensity
 	drop_zero=df[df['Tintensity']<=0].index
 	df.drop(drop_zero,inplace=True)
-	Tmass=[str(round(c*float(d)-c*1.007276,2)) for c,d in zip(df['charge'],df['Tmz'])]
+	#Tmass=[str(round(c*float(d)-c*1.007276,2)) for c,d in zip(df['charge'],df['Tmz'])]
+	Tmass=[str(round(a,2))for a in df['mz']]
 	df.loc[:,'Tmass']=Tmass
 	if not os.path.exists(result_dir):
 		os.mkdir(result_dir)
 	if not os.path.exists(result_dir+'/'+fraction):
 		os.mkdir(result_dir+'/'+fraction)
 	df.to_csv(result_dir+'/'+fraction+'/'+sample+'.csv',index=False)
+	file.close()
 	return True
 
 def pre_step(file_dir,sample_file):
@@ -121,8 +123,8 @@ def pre_step(file_dir,sample_file):
 	rows = booksheet.nrows
 	for i in range(rows):
 		raw_name = booksheet.cell_value(i,0).split('.')[0]
-		sample_name = booksheet.cell_value(i,1)
-		fraction_name = booksheet.cell_value(i,2)
+		sample_name = str(booksheet.cell_value(i,1))
+		fraction_name = str(booksheet.cell_value(i,2))
 		file_class_dics[raw_name] = sample_name
 		file_fraction_dics[raw_name] = fraction_name
 	result_dir='pre_result'
